# RL agent & gym

## Dependencies

This example requires `numpy` and `gym` in addition to the dependencies of the `aea` package.

## Run

From root execute:

`
python examples/gym_ex/train.py
`

which has the usual RL setup (that is, the `fit` method of the `RLAgent` has the typical signature and familiar implementation).